==> huaweicloudsdklts-3.1.96-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/keywords_res_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KeywordsResBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'log_stream_id': 'str',
        'log_stream_name': 'str',
        'log_group_id': 'str',
        'log_group_name': 'str',
        'keywords': 'str',
        'condition': 'str',
        'number': 'int',
        'search_time_range': 'int',
        'search_time_range_unit': 'str'
    }

    attribute_map = {
        'log_stream_id': 'log_stream_id',
        'log_stream_name': 'log_stream_name',
        'log_group_id': 'log_group_id',
        'log_group_name': 'log_group_name',
        'keywords': 'keywords',
        'condition': 'condition',
        'number': 'number',
        'search_time_range': 'search_time_range',
        'search_time_range_unit': 'search_time_range_unit'
    }

    def __init__(self, log_stream_id=None, log_stream_name=None, log_group_id=None, log_group_name=None, keywords=None, condition=None, number=None, search_time_range=None, search_time_range_unit=None):
        """KeywordsResBody

        The model defined in huaweicloud sdk

        :param log_stream_id: 日志流id
        :type log_stream_id: str
        :param log_stream_name: 日志流名称
        :type log_stream_name: str
        :param log_group_id: 日志组id
        :type log_group_id: str
        :param log_group_name: 日志组名称
        :type log_group_name: str
        :param keywords: 关键词
        :type keywords: str
        :param condition: 条件
        :type condition: str
        :param number: 行数
        :type number: int
        :param search_time_range: 查询执行任务时最近数据的时间范围，最大值为60
        :type search_time_range: int
        :param search_time_range_unit: 查询时间单位
        :type search_time_range_unit: str
        """
        
        

        self._log_stream_id = None
        self._log_stream_name = None
        self._log_group_id = None
        self._log_group_name = None
        self._keywords = None
        self._condition = None
        self._number = None
        self._search_time_range = None
        self._search_time_range_unit = None
        self.discriminator = None

        if log_stream_id is not None:
            self.log_stream_id = log_stream_id
        if log_stream_name is not None:
            self.log_stream_name = log_stream_name
        if log_group_id is not None:
            self.log_group_id = log_group_id
        if log_group_name is not None:
            self.log_group_name = log_group_name
        if keywords is not None:
            self.keywords = keywords
        if condition is not None:
            self.condition = condition
        if number is not None:
            self.number = number
        if search_time_range is not None:
            self.search_time_range = search_time_range
        if search_time_range_unit is not None:
            self.search_time_range_unit = search_time_range_unit

    @property
    def log_stream_id(self):
        """Gets the log_stream_id of this KeywordsResBody.

        日志流id

        :return: The log_stream_id of this KeywordsResBody.
        :rtype: str
        """
        return self._log_stream_id

    @log_stream_id.setter
    def log_stream_id(self, log_stream_id):
        """Sets the log_stream_id of this KeywordsResBody.

        日志流id

        :param log_stream_id: The log_stream_id of this KeywordsResBody.
        :type log_stream_id: str
        """
        self._log_stream_id = log_stream_id

    @property
    def log_stream_name(self):
        """Gets the log_stream_name of this KeywordsResBody.

        日志流名称

        :return: The log_stream_name of this KeywordsResBody.
        :rtype: str
        """
        return self._log_stream_name

    @log_stream_name.setter
    def log_stream_name(self, log_stream_name):
        """Sets the log_stream_name of this KeywordsResBody.

        日志流名称

        :param log_stream_name: The log_stream_name of this KeywordsResBody.
        :type log_stream_name: str
        """
        self._log_stream_name = log_stream_name

    @property
    def log_group_id(self):
        """Gets the log_group_id of this KeywordsResBody.

        日志组id

        :return: The log_group_id of this KeywordsResBody.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """Sets the log_group_id of this KeywordsResBody.

        日志组id

        :param log_group_id: The log_group_id of this KeywordsResBody.
        :type log_group_id: str
        """
        self._log_group_id = log_group_id

    @property
    def log_group_name(self):
        """Gets the log_group_name of this KeywordsResBody.

        日志组名称

        :return: The log_group_name of this KeywordsResBody.
        :rtype: str
        """
        return self._log_group_name

    @log_group_name.setter
    def log_group_name(self, log_group_name):
        """Sets the log_group_name of this KeywordsResBody.

        日志组名称

        :param log_group_name: The log_group_name of this KeywordsResBody.
        :type log_group_name: str
        """
        self._log_group_name = log_group_name

    @property
    def keywords(self):
        """Gets the keywords of this KeywordsResBody.

        关键词

        :return: The keywords of this KeywordsResBody.
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this KeywordsResBody.

        关键词

        :param keywords: The keywords of this KeywordsResBody.
        :type keywords: str
        """
        self._keywords = keywords

    @property
    def condition(self):
        """Gets the condition of this KeywordsResBody.

        条件

        :return: The condition of this KeywordsResBody.
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this KeywordsResBody.

        条件

        :param condition: The condition of this KeywordsResBody.
        :type condition: str
        """
        self._condition = condition

    @property
    def number(self):
        """Gets the number of this KeywordsResBody.

        行数

        :return: The number of this KeywordsResBody.
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this KeywordsResBody.

        行数

        :param number: The number of this KeywordsResBody.
        :type number: int
        """
        self._number = number

    @property
    def search_time_range(self):
        """Gets the search_time_range of this KeywordsResBody.

        查询执行任务时最近数据的时间范围，最大值为60

        :return: The search_time_range of this KeywordsResBody.
        :rtype: int
        """
        return self._search_time_range

    @search_time_range.setter
    def search_time_range(self, search_time_range):
        """Sets the search_time_range of this KeywordsResBody.

        查询执行任务时最近数据的时间范围，最大值为60

        :param search_time_range: The search_time_range of this KeywordsResBody.
        :type search_time_range: int
        """
        self._search_time_range = search_time_range

    @property
    def search_time_range_unit(self):
        """Gets the search_time_range_unit of this KeywordsResBody.

        查询时间单位

        :return: The search_time_range_unit of this KeywordsResBody.
        :rtype: str
        """
        return self._search_time_range_unit

    @search_time_range_unit.setter
    def search_time_range_unit(self, search_time_range_unit):
        """Sets the search_time_range_unit of this KeywordsResBody.

        查询时间单位

        :param search_time_range_unit: The search_time_range_unit of this KeywordsResBody.
        :type search_time_range_unit: str
        """
        self._search_time_range_unit = search_time_range_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordsResBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklts-3.1.158-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/keywords_res_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KeywordsResBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'log_stream_id': 'str',
        'log_stream_name': 'str',
        'log_group_id': 'str',
        'log_group_name': 'str',
        'keywords': 'str',
        'condition': 'str',
        'number': 'int',
        'search_time_range': 'int',
        'search_time_range_unit': 'str'
    }

    attribute_map = {
        'log_stream_id': 'log_stream_id',
        'log_stream_name': 'log_stream_name',
        'log_group_id': 'log_group_id',
        'log_group_name': 'log_group_name',
        'keywords': 'keywords',
        'condition': 'condition',
        'number': 'number',
        'search_time_range': 'search_time_range',
        'search_time_range_unit': 'search_time_range_unit'
    }

    def __init__(self, log_stream_id=None, log_stream_name=None, log_group_id=None, log_group_name=None, keywords=None, condition=None, number=None, search_time_range=None, search_time_range_unit=None):
        r"""KeywordsResBody

        The model defined in huaweicloud sdk

        :param log_stream_id: 日志流id
        :type log_stream_id: str
        :param log_stream_name: 日志流名称
        :type log_stream_name: str
        :param log_group_id: 日志组id
        :type log_group_id: str
        :param log_group_name: 日志组名称
        :type log_group_name: str
        :param keywords: 关键词
        :type keywords: str
        :param condition: 条件
        :type condition: str
        :param number: 行数
        :type number: int
        :param search_time_range: 查询执行任务时最近数据的时间范围，最大值为60
        :type search_time_range: int
        :param search_time_range_unit: 查询时间单位
        :type search_time_range_unit: str
        """
        
        

        self._log_stream_id = None
        self._log_stream_name = None
        self._log_group_id = None
        self._log_group_name = None
        self._keywords = None
        self._condition = None
        self._number = None
        self._search_time_range = None
        self._search_time_range_unit = None
        self.discriminator = None

        if log_stream_id is not None:
            self.log_stream_id = log_stream_id
        if log_stream_name is not None:
            self.log_stream_name = log_stream_name
        if log_group_id is not None:
            self.log_group_id = log_group_id
        if log_group_name is not None:
            self.log_group_name = log_group_name
        if keywords is not None:
            self.keywords = keywords
        if condition is not None:
            self.condition = condition
        if number is not None:
            self.number = number
        if search_time_range is not None:
            self.search_time_range = search_time_range
        if search_time_range_unit is not None:
            self.search_time_range_unit = search_time_range_unit

    @property
    def log_stream_id(self):
        r"""Gets the log_stream_id of this KeywordsResBody.

        日志流id

        :return: The log_stream_id of this KeywordsResBody.
        :rtype: str
        """
        return self._log_stream_id

    @log_stream_id.setter
    def log_stream_id(self, log_stream_id):
        r"""Sets the log_stream_id of this KeywordsResBody.

        日志流id

        :param log_stream_id: The log_stream_id of this KeywordsResBody.
        :type log_stream_id: str
        """
        self._log_stream_id = log_stream_id

    @property
    def log_stream_name(self):
        r"""Gets the log_stream_name of this KeywordsResBody.

        日志流名称

        :return: The log_stream_name of this KeywordsResBody.
        :rtype: str
        """
        return self._log_stream_name

    @log_stream_name.setter
    def log_stream_name(self, log_stream_name):
        r"""Sets the log_stream_name of this KeywordsResBody.

        日志流名称

        :param log_stream_name: The log_stream_name of this KeywordsResBody.
        :type log_stream_name: str
        """
        self._log_stream_name = log_stream_name

    @property
    def log_group_id(self):
        r"""Gets the log_group_id of this KeywordsResBody.

        日志组id

        :return: The log_group_id of this KeywordsResBody.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        r"""Sets the log_group_id of this KeywordsResBody.

        日志组id

        :param log_group_id: The log_group_id of this KeywordsResBody.
        :type log_group_id: str
        """
        self._log_group_id = log_group_id

    @property
    def log_group_name(self):
        r"""Gets the log_group_name of this KeywordsResBody.

        日志组名称

        :return: The log_group_name of this KeywordsResBody.
        :rtype: str
        """
        return self._log_group_name

    @log_group_name.setter
    def log_group_name(self, log_group_name):
        r"""Sets the log_group_name of this KeywordsResBody.

        日志组名称

        :param log_group_name: The log_group_name of this KeywordsResBody.
        :type log_group_name: str
        """
        self._log_group_name = log_group_name

    @property
    def keywords(self):
        r"""Gets the keywords of this KeywordsResBody.

        关键词

        :return: The keywords of this KeywordsResBody.
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        r"""Sets the keywords of this KeywordsResBody.

        关键词

        :param keywords: The keywords of this KeywordsResBody.
        :type keywords: str
        """
        self._keywords = keywords

    @property
    def condition(self):
        r"""Gets the condition of this KeywordsResBody.

        条件

        :return: The condition of this KeywordsResBody.
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        r"""Sets the condition of this KeywordsResBody.

        条件

        :param condition: The condition of this KeywordsResBody.
        :type condition: str
        """
        self._condition = condition

    @property
    def number(self):
        r"""Gets the number of this KeywordsResBody.

        行数

        :return: The number of this KeywordsResBody.
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        r"""Sets the number of this KeywordsResBody.

        行数

        :param number: The number of this KeywordsResBody.
        :type number: int
        """
        self._number = number

    @property
    def search_time_range(self):
        r"""Gets the search_time_range of this KeywordsResBody.

        查询执行任务时最近数据的时间范围，最大值为60

        :return: The search_time_range of this KeywordsResBody.
        :rtype: int
        """
        return self._search_time_range

    @search_time_range.setter
    def search_time_range(self, search_time_range):
        r"""Sets the search_time_range of this KeywordsResBody.

        查询执行任务时最近数据的时间范围，最大值为60

        :param search_time_range: The search_time_range of this KeywordsResBody.
        :type search_time_range: int
        """
        self._search_time_range = search_time_range

    @property
    def search_time_range_unit(self):
        r"""Gets the search_time_range_unit of this KeywordsResBody.

        查询时间单位

        :return: The search_time_range_unit of this KeywordsResBody.
        :rtype: str
        """
        return self._search_time_range_unit

    @search_time_range_unit.setter
    def search_time_range_unit(self, search_time_range_unit):
        r"""Sets the search_time_range_unit of this KeywordsResBody.

        查询时间单位

        :param search_time_range_unit: The search_time_range_unit of this KeywordsResBody.
        :type search_time_range_unit: str
        """
        self._search_time_range_unit = search_time_range_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordsResBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
